@@ -2,7 +2,7 @@
  * General header file configurations that apply to
  * all daemons.  System dependent stuff goes here.
  *
- *   Version $Id: baconfig.h,v 1.64.2.2 2005/02/27 21:53:28 kerns Exp $
+ *   Version $Id: baconfig.h,v 1.64.2.2.2.1 2005/04/05 17:23:32 kerns Exp $
  */
 /*
    Copyright (C) 2000-2005 Kern Sibbald
@@ -471,6 +471,18 @@ int  m_msg(const char *file, int line, POOLMEM *&pool_buf, const char *fmt, ...)
 #define bmalloc(size) b_malloc(__FILE__, __LINE__, (size))
 #endif
 
+/* =============================================================
+ *               OS Dependent defines
+  * =============================================================
+   */
+
+#ifndef HAVE_FSEEKO
+/* Bad news. This OS cannot handle 64 bit fseeks and ftells */
+#define fseeko fseek
+#define ftello ftell
+#endif
+
+
 #ifdef __alpha__
 #define OSF 1
 #endif
