@@ -18,10 +18,10 @@
  *	 Requests are any message that does not begin with a digit.
  *	 In affect, they are commands.
  *
- *   Version $Id: getmsg.c,v 1.19 2004/06/15 10:40:43 kerns Exp $
+ *   Version $Id: getmsg.c,v 1.19.8.1 2005/02/14 10:02:21 kerns Exp $
  */
 /*
-   Copyright (C) 2000-2004 Kern Sibbald and John Walker
+   Copyright (C) 2000-2005 Kern Sibbald
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -46,6 +46,8 @@
 /* Forward referenced functions */
 static char *find_msg_start(char *msg);
 
+static char Job_status[] = "Status Job=%127s JobStatus=%d\n";
+
 static char OK_msg[] = "1000 OK\n";
 
 /*
@@ -192,6 +194,15 @@ int bget_dirmsg(BSOCK *bs)
 	 free_jcr(jcr);
 	 continue;
       }
+      if (bs->msg[0] == 'S') {       /* Status change */
+	int JobStatus;
+	char Job[MAX_NAME_LENGTH];
+	if (sscanf(bs->msg, Job_status, &Job, &JobStatus) == 2) {
+	   jcr->SDJobStatus = JobStatus; /* current status */
+	   free_jcr(jcr);
+	   continue;
+	}
+      }
       return n;
    }
 }
