@@ -10,7 +10,7 @@
  *
  *  Kern Sibbald, July MMIII
  *
- *   Version $Id: jobq.c,v 1.25.4.2 2005/02/15 11:51:03 kerns Exp $
+ *   Version $Id: jobq.c,v 1.25.4.2.2.1 2005/04/05 17:23:55 kerns Exp $
  *
  *  This code was adapted from the Bacula workq, which was
  *    adapted from "Programming with POSIX Threads", by
@@ -481,7 +481,7 @@ void *jobq_server(void *arg)
 	    bstrftime(dt, sizeof(dt), time(NULL));
             Jmsg(jcr, M_INFO, 0, _("Rescheduled Job %s at %s to re-run in %d seconds.\n"),
 	       jcr->Job, dt, (int)jcr->job->RescheduleInterval);
-	    dird_free_jcr(jcr); 	 /* partial cleanup old stuff */
+	    dird_free_jcr_pointers(jcr);     /* partial cleanup old stuff */
 	    jcr->JobStatus = JS_WaitStartTime;
 	    jcr->SDJobStatus = 0;
 	    if (jcr->JobBytes == 0) {
@@ -584,7 +584,7 @@ void *jobq_server(void *arg)
 		   if (njcr->JobId == 0 || njcr == jcr) {
 		      continue;
 		   }
-		   if (njcr->pool != jcr->pool) {
+		   if (njcr->store == jcr->store && njcr->pool != jcr->pool) {
 		      skip_this_jcr = true;
 		      break;
 		   }
