@@ -13,7 +13,7 @@
  *    Create a thread to interact with the Storage daemon
  *	who returns a job status and requests Catalog services, etc.
  *
- *   Version $Id: msgchan.c,v 1.32.4.1 2005/02/14 10:02:21 kerns Exp $
+ *   Version $Id: msgchan.c,v 1.32.4.1.2.1 2005/04/05 17:23:55 kerns Exp $
  */
 /*
    Copyright (C) 2000-2004 Kern Sibbald
@@ -66,6 +66,10 @@ bool connect_to_storage_daemon(JCR *jcr, int retry_interval,
    BSOCK *sd;
    STORE *store;
 
+   if (!jcr->storage[0]) {
+      Jmsg(jcr, M_FATAL, 0, _("Attempt to contact the Storage daemon with no Storage resource.\n"));
+      return false;
+   }
    store = (STORE *)jcr->storage[0]->first();
 
    /*
