@@ -5,7 +5,7 @@
  *
  *     Kern Sibbald, September MM
  *
- *   Version $Id: ua_output.c,v 1.44 2004/04/19 14:27:01 kerns Exp $
+ *   Version $Id: ua_output.c,v 1.48 2004/11/13 10:34:17 kerns Exp $
  */
 
 /*
@@ -37,22 +37,23 @@
 extern int r_first;
 extern int r_last;
 extern RES_TABLE resources[];
+extern RES **res_head;
 extern int console_msg_pending;
 extern FILE *con_fd;
 extern brwlock_t con_lock;
 
-
 /* Imported functions */
 
 /* Forward referenced functions */
-static int do_list_cmd(UAContext *ua, char *cmd, e_list_type llist);
+static int do_list_cmd(UAContext *ua, const char *cmd, e_list_type llist);
+static bool list_nextvol(UAContext *ua);
 
 /*
  * Turn auto display of console messages on/off
  */
-int autodisplay_cmd(UAContext *ua, char *cmd)
+int autodisplay_cmd(UAContext *ua, const char *cmd)
 {
-   static char *kw[] = {
+   static const char *kw[] = {
       N_("on"), 
       N_("off"),
       NULL};
@@ -74,9 +75,9 @@ int autodisplay_cmd(UAContext *ua, char *cmd)
 /*
  * Turn gui processing on/off
  */
-int gui_cmd(UAContext *ua, char *cmd)
+int gui_cmd(UAContext *ua, const char *cmd)
 {
-   static char *kw[] = {
+   static const char *kw[] = {
       N_("on"), 
       N_("off"),
       NULL};
@@ -97,7 +98,7 @@ int gui_cmd(UAContext *ua, char *cmd)
 
 
 
-struct showstruct {char *res_name; int type;};
+struct showstruct {const char *res_name; int type;};
 static struct showstruct reses[] = {
    {N_("directors"),  R_DIRECTOR},
    {N_("clients"),    R_CLIENT},
@@ -123,7 +124,7 @@ static struct showstruct reses[] = {
  *  show <resource-keyword-name>=<name> e.g. show director=HeadMan
  *
  */
-int show_cmd(UAContext *ua, char *cmd)
+int show_cmd(UAContext *ua, const char *cmd)
 {
    int i, j, type, len; 
    int recurse;
@@ -145,7 +146,8 @@ int show_cmd(UAContext *ua, char *cmd)
 	    if (strncasecmp(res_name, _(reses[j].res_name), len) == 0) {
 	       type = reses[j].type;
 	       if (type > 0) {
-		  res = resources[type-r_first].res_head;
+		  res = res_head[type-r_first];
+//		  res = resources[type-r_first].res_head;
 	       } else {
 		  res = NULL;
 	       }
@@ -172,7 +174,8 @@ int show_cmd(UAContext *ua, char *cmd)
       switch (type) {
       case -1:				 /* all */
 	 for (j=r_first; j<=r_last; j++) {
-	    dump_resource(j, resources[j-r_first].res_head, bsendmsg, ua);     
+	    dump_resource(j, res_head[j-r_first], bsendmsg, ua);     
+//	    dump_resource(j, resources[j-r_first].res_head, bsendmsg, ua);     
 	 }
 	 break;
       case -2:
@@ -221,18 +224,18 @@ bail_out:
  */
 
 /* Do long or full listing */
-int llist_cmd(UAContext *ua, char *cmd)
+int llist_cmd(UAContext *ua, const char *cmd)
 {
    return do_list_cmd(ua, cmd, VERT_LIST);
 }
 
 /* Do short or summary listing */
-int list_cmd(UAContext *ua, char *cmd)
+int list_cmd(UAContext *ua, const char *cmd)
 {
    return do_list_cmd(ua, cmd, HORZ_LIST);
 }
 
-static int do_list_cmd(UAContext *ua, char *cmd, e_list_type llist)
+static int do_list_cmd(UAContext *ua, const char *cmd, e_list_type llist)
 {
    POOLMEM *VolumeName;
    int jobid, n;
@@ -398,58 +401,7 @@ static int do_list_cmd(UAContext *ua, char *cmd, e_list_type llist)
       /* List next volume */
       } else if (strcasecmp(ua->argk[i], _("nextvol")) == 0 || 
                  strcasecmp(ua->argk[i], _("nextvolume")) == 0) {
-	 JOB *job;
-	 JCR *jcr = ua->jcr;
-	 POOL *pool;
-	 RUN *run;
-	 time_t runtime;
-	 bool found = false;
-
-         i = find_arg_with_value(ua, "job");
-	 if (i <= 0) {
-	    if ((job = select_job_resource(ua)) == NULL) {
-	       return 1;
-	    }
-	 } else {
-	    job = (JOB *)GetResWithName(R_JOB, ua->argv[i]);
-	    if (!job) {
-               Jmsg(jcr, M_ERROR, 0, _("%s is not a job name.\n"), ua->argv[i]);
-	       if ((job = select_job_resource(ua)) == NULL) {
-		  return 1;
-	       }
-	    }
-	 }
-	 for (run=NULL; (run = find_next_run(run, job, runtime)); ) {
-	    pool = run ? run->pool : NULL;
-	    if (!complete_jcr_for_job(jcr, job, pool)) {
-	       return 1;
-	    }
-	   
-	    if (!find_next_volume_for_append(jcr, &mr, 0)) {
-               bsendmsg(ua, _("Could not find next Volume.\n"));
-	       if (jcr->db) {
-		  db_close_database(jcr, jcr->db);
-		  jcr->db = NULL;
-	       }
-	       return 1;
-	    } else {
-               bsendmsg(ua, _("The next Volume to be used by Job \"%s\" will be %s\n"), 
-		  job->hdr.name, mr.VolumeName);
-	       found = true;
-	    }
-	    if (jcr->db) {
-	       db_close_database(jcr, jcr->db);
-	       jcr->db = NULL;
-	    }
-	 }
-	 if (jcr->db) {
-	    db_close_database(jcr, jcr->db);
-	    jcr->db = NULL;
-	 }
-	 if (!found) {
-            bsendmsg(ua, _("Could not find next Volume.\n"));
-	 }
-	 return 1;
+	 list_nextvol(ua);
       } else {
          bsendmsg(ua, _("Unknown list keyword: %s\n"), NPRT(ua->argk[i]));
       }
@@ -457,6 +409,57 @@ static int do_list_cmd(UAContext *ua, char *cmd, e_list_type llist)
    return 1;
 }
 
+static bool list_nextvol(UAContext *ua)
+{
+   JOB *job;
+   JCR *jcr = ua->jcr;
+   POOL *pool;
+   RUN *run;
+   time_t runtime;
+   bool found = false;
+   MEDIA_DBR mr;
+
+   memset(&mr, 0, sizeof(mr));
+   int i = find_arg_with_value(ua, "job");
+   if (i <= 0) {
+      if ((job = select_job_resource(ua)) == NULL) {
+	 return false;
+      }
+   } else {
+      job = (JOB *)GetResWithName(R_JOB, ua->argv[i]);
+      if (!job) {
+         Jmsg(jcr, M_ERROR, 0, _("%s is not a job name.\n"), ua->argv[i]);
+	 if ((job = select_job_resource(ua)) == NULL) {
+	    return false;
+	 }
+      }
+   }
+   for (run=NULL; (run = find_next_run(run, job, runtime)); ) {
+      pool = run ? run->pool : NULL;
+      if (!complete_jcr_for_job(jcr, job, pool)) {
+	 return false;
+      }
+     
+      if (!find_next_volume_for_append(jcr, &mr, 0)) {
+         bsendmsg(ua, _("Could not find next Volume.\n"));
+      } else {
+         bsendmsg(ua, _("The next Volume to be used by Job \"%s\" will be %s\n"), 
+	    job->hdr.name, mr.VolumeName);
+	 found = true;
+      }
+      if (jcr->db && jcr->db != ua->db) {
+	 db_close_database(jcr, jcr->db);
+	 jcr->db = NULL;
+      }
+   }
+   if (!found) {
+      bsendmsg(ua, _("Could not find next Volume.\n"));
+      return false;
+   }
+   return true;
+}
+
+
 /* 
  * For a given job, we examine all his run records
  *  to see if it is scheduled today or tomorrow.
@@ -583,7 +586,8 @@ int complete_jcr_for_job(JCR *jcr, JOB *job, POOL *pool)
    }
    jcr->db = jcr->db=db_init_database(jcr, jcr->catalog->db_name, jcr->catalog->db_user,
 		      jcr->catalog->db_password, jcr->catalog->db_address,
-		      jcr->catalog->db_port, jcr->catalog->db_socket);
+		      jcr->catalog->db_port, jcr->catalog->db_socket,	
+		      jcr->catalog->mult_db_connections);
    if (!jcr->db || !db_open_database(jcr, jcr->db)) {
       Jmsg(jcr, M_FATAL, 0, _("Could not open database \"%s\".\n"),
 		 jcr->catalog->db_name);
@@ -618,7 +622,7 @@ static void con_lock_release(void *arg)
    Vw(con_lock);
 }
 
-void do_messages(UAContext *ua, char *cmd)
+void do_messages(UAContext *ua, const char *cmd)
 {
    char msg[2000];
    int mlen; 
@@ -645,7 +649,7 @@ void do_messages(UAContext *ua, char *cmd)
 }
 
 
-int qmessagescmd(UAContext *ua, char *cmd)
+int qmessagescmd(UAContext *ua, const char *cmd)
 {
    if (console_msg_pending && ua->auto_display_messages) {
       do_messages(ua, cmd);
@@ -653,7 +657,7 @@ int qmessagescmd(UAContext *ua, char *cmd)
    return 1;
 }
 
-int messagescmd(UAContext *ua, char *cmd)
+int messagescmd(UAContext *ua, const char *cmd)
 {
    if (console_msg_pending) {
       do_messages(ua, cmd);
@@ -666,7 +670,7 @@ int messagescmd(UAContext *ua, char *cmd)
 /*
  * Callback routine for "printing" database file listing
  */
-void prtit(void *ctx, char *msg)
+void prtit(void *ctx, const char *msg)
 {
    UAContext *ua = (UAContext *)ctx;
  
@@ -680,7 +684,7 @@ void prtit(void *ctx, char *msg)
  * agent, so we are being called from Bacula core. In
  * that case direct the messages to the Job.
  */
-void bsendmsg(void *ctx, char *fmt, ...)
+void bsendmsg(void *ctx, const char *fmt, ...)
 {
    va_list arg_ptr;
    UAContext *ua = (UAContext *)ctx;
