@@ -3,7 +3,7 @@
  *
  *    Kern Sibbald, October MM
  *
- *   Version $Id: job.c,v 1.91.4.2 2005/02/25 09:47:06 kerns Exp $
+ *   Version $Id: job.c,v 1.91.4.2.2.1 2005/03/04 09:14:16 kerns Exp $
  *
  */
 /*
@@ -1139,7 +1139,7 @@ static int level_cmd(JCR *jcr)
       buf = get_memory(dir->msglen+1);
       utime_t since_time, adj;
       btime_t his_time, bt_start, rt=0, bt_adj=0;
-      if (jcr->JobLevel == 0) {
+      if (jcr->JobLevel == L_NONE) {
 	 jcr->JobLevel = L_SINCE;     /* if no other job level set, do it now */
       }
       if (sscanf(dir->msg, "level = since_utime %s mtime_only=%d",
