@@ -3,7 +3,7 @@
  *
  *    Kern Sibbald, November MM
  *
- *   Version $Id: create_file.c,v 1.34 2004/07/27 21:00:33 kerns Exp $
+ *   Version $Id: create_file.c,v 1.34.10.2 2005/04/12 21:31:20 kerns Exp $
  *
  */
 /*
@@ -271,6 +271,12 @@ int create_file(JCR *jcr, ATTR *attr, BFILE *bfd, int replace)
 	 if ((bopen(bfd, attr->ofname, O_WRONLY|O_BINARY, 0)) < 0) {
 	    berrno be;
 	    be.set_errno(bfd->berrno);
+#ifdef HAVE_WIN32
+	    /* Check for trying to create a drive, if so, skip */
+            if (attr->ofname[1] == ':' && attr->ofname[2] == '/' && attr->ofname[3] == 0) {
+	       return CF_SKIP;
+	    }
+#endif
             Jmsg2(jcr, M_ERROR, 0, _("Could not open %s: ERR=%s\n"), 
 		  attr->ofname, be.strerror());
 	    return CF_ERROR;
