@@ -2,18 +2,18 @@
  *
  *   dev.c  -- low level operations on device (storage device)
  *
- *		Kern Sibbald, MM 
+ *              Kern Sibbald, MM 
  *
  *     NOTE!!!! None of these routines are reentrant. You must
- *	  use lock_device() and unlock_device() at a higher level,
- *	  or use the xxx_device() equivalents.	By moving the
- *	  thread synchronization to a higher level, we permit
+ *        use lock_device() and unlock_device() at a higher level,
+ *        or use the xxx_device() equivalents.  By moving the
+ *        thread synchronization to a higher level, we permit
  *        the higher level routines to "seize" the device and 
- *	  to carry out operations without worrying about who
- *	  set what lock (i.e. race conditions).
+ *        to carry out operations without worrying about who
+ *        set what lock (i.e. race conditions).
  *
  *     Note, this is the device dependent code, and my have
- *	     to be modified for each system, but is meant to
+ *           to be modified for each system, but is meant to
  *           be as "generic" as possible.
  * 
  *     The purpose of this code is to develop a SIMPLE Storage
@@ -26,7 +26,7 @@
  *     really necessary -- KES.  Note, this contortion has been
  *     corrected to a large extent by a rewrite (Apr MMI).
  *
- *   Version $Id: dev.c,v 1.95.2.1 2005/02/14 10:02:27 kerns Exp $
+ *   Version $Id: dev.c,v 1.95.2.1.2.1 2005/04/12 21:31:21 kerns Exp $
  */
 /*
    Copyright (C) 2000-2004 Kern Sibbald and John Walker
@@ -106,10 +106,10 @@ init_dev(DEVICE *dev, DEVRES *device)
    if (stat(device->device_name, &statp) < 0) {
       berrno be;
       if (dev) {
-	 dev->dev_errno = errno;
+         dev->dev_errno = errno;
       } 
       Emsg2(M_FATAL, 0, "Unable to stat device %s : %s\n", device->device_name, 
-	    be.strerror());
+            be.strerror());
       return NULL;
    }
    tape = false;
@@ -122,10 +122,10 @@ init_dev(DEVICE *dev, DEVRES *device)
       fifo = true;
    } else {
       if (dev) {
-	 dev->dev_errno = ENODEV;
+         dev->dev_errno = ENODEV;
       }
       Emsg2(M_FATAL, 0, _("%s is an unknown device type. Must be tape or directory. st_mode=%x\n"),
-	 device->device_name, statp.st_mode);
+         device->device_name, statp.st_mode);
       return NULL;
    }
    if (!dev) {
@@ -168,14 +168,14 @@ init_dev(DEVICE *dev, DEVRES *device)
 
    if (dev->max_block_size > 1000000) {
       Emsg3(M_ERROR, 0, _("Block size %u on device %s is too large, using default %u\n"), 
-	 dev->max_block_size, dev->dev_name, DEFAULT_BLOCK_SIZE);
+         dev->max_block_size, dev->dev_name, DEFAULT_BLOCK_SIZE);
       dev->max_block_size = 0;
    }
    if (dev->max_block_size % TAPE_BSIZE != 0) {
       Emsg2(M_WARNING, 0, _("Max block size %u not multiple of device %s block size.\n"),
-	 dev->max_block_size, dev->dev_name);
+         dev->max_block_size, dev->dev_name);
    }   
-	 
+         
    dev->errmsg = get_pool_memory(PM_EMSG);
    *dev->errmsg = 0;
 
@@ -239,11 +239,11 @@ open_dev(DEVICE *dev, char *VolName, int mode)
        *  starts and snatches up the device.
        */
       if (VolName && strcmp(dev->VolCatInfo.VolCatName, VolName) != 0) {
-	 return -1;
+         return -1;
       }
       dev->use_count++;
       Mmsg2(&dev->errmsg, _("WARNING!!!! device %s opened %d times!!!\n"), 
-	    dev->dev_name, dev->use_count);
+            dev->dev_name, dev->use_count);
       Emsg1(M_WARNING, 0, "%s", dev->errmsg);
       return dev->fd;
    }
@@ -252,60 +252,60 @@ open_dev(DEVICE *dev, char *VolName, int mode)
    }
 
    Dmsg3(29, "open_dev: tape=%d dev_name=%s vol=%s\n", dev_is_tape(dev), 
-	 dev->dev_name, dev->VolCatInfo.VolCatName);
+         dev->dev_name, dev->VolCatInfo.VolCatName);
    dev->state &= ~(ST_LABEL|ST_APPEND|ST_READ|ST_EOT|ST_WEOT|ST_EOF);
    dev->file_size = 0;
    if (dev->state & (ST_TAPE|ST_FIFO)) {
       int timeout;
       Dmsg0(29, "open_dev: device is tape\n");
       if (mode == OPEN_READ_WRITE) {
-	 dev->mode = O_RDWR | O_BINARY;
+         dev->mode = O_RDWR | O_BINARY;
       } else if (mode == OPEN_READ_ONLY) {
-	 dev->mode = O_RDONLY | O_BINARY;
+         dev->mode = O_RDONLY | O_BINARY;
       } else if (mode == OPEN_WRITE_ONLY) {
-	 dev->mode = O_WRONLY | O_BINARY;
+         dev->mode = O_WRONLY | O_BINARY;
       } else {
          Emsg0(M_ABORT, 0, _("Illegal mode given to open_dev.\n")); 
       }
       timeout = dev->max_open_wait;
       errno = 0;
       if (dev->state & ST_FIFO && timeout) {
-	 /* Set open timer */
-	 dev->tid = start_thread_timer(pthread_self(), timeout);
+         /* Set open timer */
+         dev->tid = start_thread_timer(pthread_self(), timeout);
       }
       /* If busy retry each second for max_open_wait seconds */
       while ((dev->fd = open(dev->dev_name, dev->mode, MODE_RW)) < 0) {
-	 berrno be;
-	 if (errno == EINTR || errno == EAGAIN) {
-	    continue;
-	 }
-	 if (errno == EBUSY && timeout-- > 0) {
+         berrno be;
+         if (errno == EINTR || errno == EAGAIN) {
+            continue;
+         }
+         if (errno == EBUSY && timeout-- > 0) {
             Dmsg2(100, "Device %s busy. ERR=%s\n", dev->dev_name, be.strerror());
-	    bmicrosleep(1, 0);
-	    continue;
-	 }
-	 dev->dev_errno = errno;
+            bmicrosleep(1, 0);
+            continue;
+         }
+         dev->dev_errno = errno;
          Mmsg2(&dev->errmsg, _("stored: unable to open device %s: ERR=%s\n"), 
-	       dev->dev_name, be.strerror());
-	 /* Stop any open timer we set */
-	 if (dev->tid) {
-	    stop_thread_timer(dev->tid);
-	    dev->tid = 0;
-	 }
-	 Emsg0(M_FATAL, 0, dev->errmsg);
-	 break;
+               dev->dev_name, be.strerror());
+         /* Stop any open timer we set */
+         if (dev->tid) {
+            stop_thread_timer(dev->tid);
+            dev->tid = 0;
+         }
+         Emsg0(M_FATAL, 0, dev->errmsg);
+         break;
       }
       if (dev->fd >= 0) {
-	 dev->dev_errno = 0;
-	 dev->state |= ST_OPENED;
-	 dev->use_count = 1;
-	 update_pos_dev(dev);		  /* update position */
-	 set_os_device_parameters(dev);      /* do system dependent stuff */
+         dev->dev_errno = 0;
+         dev->state |= ST_OPENED;
+         dev->use_count = 1;
+         update_pos_dev(dev);             /* update position */
+         set_os_device_parameters(dev);      /* do system dependent stuff */
       }
       /* Stop any open() timer we started */
       if (dev->tid) {
-	 stop_thread_timer(dev->tid);
-	 dev->tid = 0;
+         stop_thread_timer(dev->tid);
+         dev->tid = 0;
       }
       Dmsg1(29, "open_dev: tape %d opened\n", dev->fd);
    } else {
@@ -314,8 +314,8 @@ open_dev(DEVICE *dev, char *VolName, int mode)
        */
       if (VolName == NULL || *VolName == 0) {
          Mmsg(dev->errmsg, _("Could not open file device %s. No Volume name given.\n"),
-	    dev->dev_name);
-	 return -1;
+            dev->dev_name);
+         return -1;
       }
       archive_name = get_pool_memory(PM_FNAME);
       pm_strcpy(archive_name, dev->dev_name);
@@ -325,25 +325,25 @@ open_dev(DEVICE *dev, char *VolName, int mode)
       pm_strcat(archive_name, VolName);
       Dmsg1(29, "open_dev: device is disk %s\n", archive_name);
       if (mode == OPEN_READ_WRITE) {
-	 dev->mode = O_CREAT | O_RDWR | O_BINARY;
+         dev->mode = O_CREAT | O_RDWR | O_BINARY;
       } else if (mode == OPEN_READ_ONLY) {
-	 dev->mode = O_RDONLY | O_BINARY;
+         dev->mode = O_RDONLY | O_BINARY;
       } else if (mode == OPEN_WRITE_ONLY) {
-	 dev->mode = O_WRONLY | O_BINARY;
+         dev->mode = O_WRONLY | O_BINARY;
       } else {
          Emsg0(M_ABORT, 0, _("Illegal mode given to open_dev.\n")); 
       }
       /* If creating file, give 0640 permissions */
       if ((dev->fd = open(archive_name, dev->mode, 0640)) < 0) {
-	 berrno be;
-	 dev->dev_errno = errno;
+         berrno be;
+         dev->dev_errno = errno;
          Mmsg2(&dev->errmsg, _("Could not open: %s, ERR=%s\n"), archive_name, be.strerror());
-	 Emsg0(M_FATAL, 0, dev->errmsg);
+         Emsg0(M_FATAL, 0, dev->errmsg);
       } else {
-	 dev->dev_errno = 0;
-	 dev->state |= ST_OPENED;
-	 dev->use_count = 1;
-	 update_pos_dev(dev);		     /* update position */
+         dev->dev_errno = 0;
+         dev->state |= ST_OPENED;
+         dev->use_count = 1;
+         update_pos_dev(dev);                /* update position */
       }
       Dmsg1(29, "open_dev: disk fd=%d opened\n", dev->fd);
       free_pool_memory(archive_name);
@@ -364,7 +364,7 @@ bool _rewind_dev(char *file, int line, DEVICE *dev)
 /*
  * Rewind the device.
  *  Returns: true  on success
- *	     false on failure
+ *           false on failure
  */
 bool rewind_dev(DEVICE *dev)
 {
@@ -375,7 +375,7 @@ bool rewind_dev(DEVICE *dev)
    if (dev->fd < 0) {
       dev->dev_errno = EBADF;
       Mmsg1(&dev->errmsg, _("Bad call to rewind_dev. Device %s not open\n"),
-	    dev->dev_name);
+            dev->dev_name);
       Emsg0(M_ABORT, 0, dev->errmsg);
       return false;
    }
@@ -391,30 +391,30 @@ bool rewind_dev(DEVICE *dev)
        * retrying every 5 seconds.
        */
       for (i=dev->max_rewind_wait; ; i -= 5) {
-	 if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	    berrno be;
-	    clrerror_dev(dev, MTREW);
-	    if (i == dev->max_rewind_wait) {
+         if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
+            berrno be;
+            clrerror_dev(dev, MTREW);
+            if (i == dev->max_rewind_wait) {
                Dmsg1(200, "Rewind error, %s. retrying ...\n", be.strerror());
-	    }
-	    if (dev->dev_errno == EIO && i > 0) {
+            }
+            if (dev->dev_errno == EIO && i > 0) {
                Dmsg0(200, "Sleeping 5 seconds.\n");
-	       bmicrosleep(5, 0);
-	       continue;
-	    }
+               bmicrosleep(5, 0);
+               continue;
+            }
             Mmsg2(&dev->errmsg, _("Rewind error on %s. ERR=%s.\n"),
-	       dev->dev_name, be.strerror());
-	    return false;
-	 }
-	 break;
+               dev->dev_name, be.strerror());
+            return false;
+         }
+         break;
       }
    } else if (dev->state & ST_FILE) {
       if (lseek(dev->fd, (off_t)0, SEEK_SET) < 0) {
-	 berrno be;
-	 dev->dev_errno = errno;
+         berrno be;
+         dev->dev_errno = errno;
          Mmsg2(&dev->errmsg, _("lseek error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 return false;
+            dev->dev_name, be.strerror());
+         return false;
       }
    }
    return true;
@@ -423,7 +423,7 @@ bool rewind_dev(DEVICE *dev)
 /* 
  * Position device to end of medium (end of data)
  *  Returns: 1 on succes
- *	     0 on error
+ *           0 on error
  */
 int 
 eod_dev(DEVICE *dev)
@@ -448,14 +448,14 @@ eod_dev(DEVICE *dev)
       pos = lseek(dev->fd, (off_t)0, SEEK_END);
 //    Dmsg1(100, "====== Seek to %lld\n", pos);
       if (pos >= 0) {
-	 update_pos_dev(dev);
-	 dev->state |= ST_EOT;
-	 return 1;
+         update_pos_dev(dev);
+         dev->state |= ST_EOT;
+         return 1;
       }
       dev->dev_errno = errno;
       berrno be;
       Mmsg2(&dev->errmsg, _("lseek error on %s. ERR=%s.\n"),
-	     dev->dev_name, be.strerror());
+             dev->dev_name, be.strerror());
       return 0;
    }
 #ifdef MTEOM
@@ -464,9 +464,9 @@ eod_dev(DEVICE *dev)
       struct mtget mt_stat;
       Dmsg0(100,"Using FAST FSF for EOM\n");
       if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) == 0 && mt_stat.mt_fileno <= 0) {
-	if (!rewind_dev(dev)) {
-	  return 0;
-	}
+        if (!rewind_dev(dev)) {
+          return 0;
+        }
       }
       mt_com.mt_op = MTFSF;
       /*
@@ -475,7 +475,7 @@ eod_dev(DEVICE *dev)
        */
       mt_com.mt_count = INT16_MAX;    /* use big positive number */
       if (mt_com.mt_count < 0) {
-	 mt_com.mt_count = INT16_MAX; /* brain damaged system */
+         mt_com.mt_count = INT16_MAX; /* brain damaged system */
       }
    }
 
@@ -486,21 +486,21 @@ eod_dev(DEVICE *dev)
    }
    if (dev_cap(dev, CAP_FASTFSF) || dev_cap(dev, CAP_EOM)) {
       if ((stat=ioctl(dev->fd, MTIOCTOP, (char *)&mt_com)) < 0) {
-	 berrno be;
-	 clrerror_dev(dev, mt_com.mt_op);
+         berrno be;
+         clrerror_dev(dev, mt_com.mt_op);
          Dmsg1(50, "ioctl error: %s\n", be.strerror());
-	 update_pos_dev(dev);
+         update_pos_dev(dev);
          Mmsg2(&dev->errmsg, _("ioctl MTEOM error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 return 0;
+            dev->dev_name, be.strerror());
+         return 0;
       }
 
       if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) < 0) {
-	 berrno be;
-	 clrerror_dev(dev, -1);
+         berrno be;
+         clrerror_dev(dev, -1);
          Mmsg2(&dev->errmsg, _("ioctl MTIOCGET error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 return 0;
+            dev->dev_name, be.strerror());
+         return 0;
       }
       Dmsg2(100, "EOD file=%d block=%d\n", mt_stat.mt_fileno, mt_stat.mt_blkno);
       dev->file = mt_stat.mt_fileno;
@@ -513,7 +513,7 @@ eod_dev(DEVICE *dev)
    {
 #endif
       if (!rewind_dev(dev)) {
-	 return 0;
+         return 0;
       }
       /* 
        * Move file by file to the end of the tape
@@ -521,27 +521,27 @@ eod_dev(DEVICE *dev)
       int file_num;
       for (file_num=dev->file; !(dev->state & ST_EOT); file_num++) {
          Dmsg0(200, "eod_dev: doing fsf 1\n");
-	 if (!fsf_dev(dev, 1)) {
+         if (!fsf_dev(dev, 1)) {
             Dmsg0(200, "fsf_dev error.\n");
-	    return 0;
-	 }
-	 /*
-	  * Avoid infinite loop. ***FIXME*** possibly add code
-	  *   to set EOD or to turn off CAP_FASTFSF if on.
-	  */
-	 if (file_num == (int)dev->file) {
-	    struct mtget mt_stat;
+            return 0;
+         }
+         /*
+          * Avoid infinite loop. ***FIXME*** possibly add code
+          *   to set EOD or to turn off CAP_FASTFSF if on.
+          */
+         if (file_num == (int)dev->file) {
+            struct mtget mt_stat;
             Dmsg1(100, "fsf_dev did not advance from file %d\n", file_num);
 #ifndef HAVE_OPENBSD_OS
-	    if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) == 0 && 
-		      mt_stat.mt_fileno >= 0) {
+            if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) == 0 && 
+                      mt_stat.mt_fileno >= 0) {
                Dmsg2(100, "Adjust file from %d to %d\n", dev->file , mt_stat.mt_fileno);
-	       dev->file = mt_stat.mt_fileno;
-	    }
+               dev->file = mt_stat.mt_fileno;
+            }
 #endif
-	    stat = 0;
-	    break;		      /* we are not progressing, bail out */
-	 }
+            stat = 0;
+            break;                    /* we are not progressing, bail out */
+         }
       }
    }
    /*
@@ -556,12 +556,12 @@ eod_dev(DEVICE *dev)
       /* If BSF worked and fileno is known (not -1), set file */
       if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) == 0 && mt_stat.mt_fileno >= 0) {
          Dmsg2(100, "BSFATEOF adjust file from %d to %d\n", dev->file , mt_stat.mt_fileno);
-	 dev->file = mt_stat.mt_fileno;
+         dev->file = mt_stat.mt_fileno;
       } else {
-	 dev->file++;		      /* wing it -- not correct on all OSes */
+         dev->file++;                 /* wing it -- not correct on all OSes */
       }
    } else {
-      update_pos_dev(dev);		     /* update position */
+      update_pos_dev(dev);                   /* update position */
       stat = 1;
    }
    Dmsg1(200, "EOD dev->file=%d\n", dev->file);
@@ -572,7 +572,7 @@ eod_dev(DEVICE *dev)
  * Set the position of the device -- only for files
  *   For other devices, there is no generic way to do it.
  *  Returns: true  on succes
- *	     false on error
+ *           false on error
  */
 bool update_pos_dev(DEVICE *dev)
 {
@@ -592,14 +592,14 @@ bool update_pos_dev(DEVICE *dev)
       dev->file_addr = 0;
       pos = lseek(dev->fd, (off_t)0, SEEK_CUR);
       if (pos < 0) {
-	 berrno be;
-	 dev->dev_errno = errno;
+         berrno be;
+         dev->dev_errno = errno;
          Pmsg1(000, "Seek error: ERR=%s\n", be.strerror());
          Mmsg2(&dev->errmsg, _("lseek error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 ok = false;
+            dev->dev_name, be.strerror());
+         ok = false;
       } else {
-	 dev->file_addr = pos;
+         dev->file_addr = pos;
       }
    }
    return ok;
@@ -633,49 +633,49 @@ uint32_t status_dev(DEVICE *dev)
       Dmsg0(-20," Bacula status:");
       Dmsg2(-20," file=%d block=%d\n", dev->file, dev->block_num);
       if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) < 0) {
-	 berrno be;
-	 dev->dev_errno = errno;
+         berrno be;
+         dev->dev_errno = errno;
          Mmsg2(&dev->errmsg, _("ioctl MTIOCGET error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 return 0;
+            dev->dev_name, be.strerror());
+         return 0;
       }
       Dmsg0(-20, " Device status:");
 
 #if defined(HAVE_LINUX_OS)
       if (GMT_EOF(mt_stat.mt_gstat)) {
-	 stat |= BMT_EOF;
+         stat |= BMT_EOF;
          Dmsg0(-20, " EOF");
       }
       if (GMT_BOT(mt_stat.mt_gstat)) {
-	 stat |= BMT_BOT;
+         stat |= BMT_BOT;
          Dmsg0(-20, " BOT");
       }
       if (GMT_EOT(mt_stat.mt_gstat)) {
-	 stat |= BMT_EOT;
+         stat |= BMT_EOT;
          Dmsg0(-20, " EOT");
       }
       if (GMT_SM(mt_stat.mt_gstat)) {
-	 stat |= BMT_SM;
+         stat |= BMT_SM;
          Dmsg0(-20, " SM");
       }
       if (GMT_EOD(mt_stat.mt_gstat)) {
-	 stat |= BMT_EOD;
+         stat |= BMT_EOD;
          Dmsg0(-20, " EOD");
       }
       if (GMT_WR_PROT(mt_stat.mt_gstat)) {
-	 stat |= BMT_WR_PROT;
+         stat |= BMT_WR_PROT;
          Dmsg0(-20, " WR_PROT");
       }
       if (GMT_ONLINE(mt_stat.mt_gstat)) {
-	 stat |= BMT_ONLINE;
+         stat |= BMT_ONLINE;
          Dmsg0(-20, " ONLINE");
       }
       if (GMT_DR_OPEN(mt_stat.mt_gstat)) {
-	 stat |= BMT_DR_OPEN;
+         stat |= BMT_DR_OPEN;
          Dmsg0(-20, " DR_OPEN");       
       }
       if (GMT_IM_REP_EN(mt_stat.mt_gstat)) {
-	 stat |= BMT_IM_REP_EN;
+         stat |= BMT_IM_REP_EN;
          Dmsg0(-20, " IM_REP_EN");
       }
 #endif /* !SunOS && !OSF */
@@ -690,7 +690,7 @@ uint32_t status_dev(DEVICE *dev)
 /*
  * Load medium in device
  *  Returns: true  on success
- *	     false on failure
+ *           false on failure
  */
 bool load_dev(DEVICE *dev)
 {
@@ -710,9 +710,9 @@ bool load_dev(DEVICE *dev)
 #ifndef MTLOAD
    Dmsg0(200, "stored: MTLOAD command not available\n");
    berrno be;
-   dev->dev_errno = ENOTTY;	      /* function not available */
+   dev->dev_errno = ENOTTY;           /* function not available */
    Mmsg2(&dev->errmsg, _("ioctl MTLOAD error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+         dev->dev_name, be.strerror());
    return false;
 #else
 
@@ -725,7 +725,7 @@ bool load_dev(DEVICE *dev)
       berrno be;
       dev->dev_errno = errno;
       Mmsg2(&dev->errmsg, _("ioctl MTLOAD error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+         dev->dev_name, be.strerror());
       return false;
    }
    return true;
@@ -735,7 +735,7 @@ bool load_dev(DEVICE *dev)
 /*
  * Rewind device and put it offline
  *  Returns: true  on success
- *	     false on failure
+ *           false on failure
  */
 bool offline_dev(DEVICE *dev)
 {
@@ -766,7 +766,7 @@ bool offline_dev(DEVICE *dev)
       berrno be;
       dev->dev_errno = errno;
       Mmsg2(&dev->errmsg, _("ioctl MTOFFL error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+         dev->dev_name, be.strerror());
       return false;
    }
    Dmsg1(100, "Offlined device %s\n", dev->dev_name);
@@ -781,7 +781,7 @@ bool offline_or_rewind_dev(DEVICE *dev)
    if (dev_cap(dev, CAP_OFFLINEUNMOUNT)) {
       return offline_dev(dev);
    } else {
-   /*		 
+   /*            
     * Note, this rewind probably should not be here (it wasn't
     *  in prior versions of Bacula), but on FreeBSD, this is
     *  needed in the case the tape was "frozen" due to an error
@@ -794,9 +794,9 @@ bool offline_or_rewind_dev(DEVICE *dev)
 }
 
 /* 
- * Foward space a file	
+ * Foward space a file  
  *   Returns: true  on success
- *	      false on failure
+ *            false on failure
  */
 bool
 fsf_dev(DEVICE *dev, int num)
@@ -838,18 +838,18 @@ fsf_dev(DEVICE *dev, int num)
       mt_com.mt_count = num;
       stat = ioctl(dev->fd, MTIOCTOP, (char *)&mt_com);
       if (stat < 0 || ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) < 0) {
-	 berrno be;
-	 dev->state |= ST_EOT;
+         berrno be;
+         dev->state |= ST_EOT;
          Dmsg0(200, "Set ST_EOT\n");
-	 clrerror_dev(dev, MTFSF);
+         clrerror_dev(dev, MTFSF);
          Mmsg2(dev->errmsg, _("ioctl MTFSF error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
+            dev->dev_name, be.strerror());
          Dmsg1(200, "%s", dev->errmsg);
-	 return false;
+         return false;
       }
       Dmsg2(200, "fsf file=%d block=%d\n", mt_stat.mt_fileno, mt_stat.mt_blkno);
       dev->file = mt_stat.mt_fileno;
-      dev->state |= ST_EOF;	/* just read EOF */
+      dev->state |= ST_EOF;     /* just read EOF */
       dev->file_addr = 0;
       dev->file_size = 0;
       return true;
@@ -866,66 +866,66 @@ fsf_dev(DEVICE *dev, int num)
       int rbuf_len;
       Dmsg0(200, "FSF has cap_fsf\n");
       if (dev->max_block_size == 0) {
-	 rbuf_len = DEFAULT_BLOCK_SIZE;
+         rbuf_len = DEFAULT_BLOCK_SIZE;
       } else {
-	 rbuf_len = dev->max_block_size;
+         rbuf_len = dev->max_block_size;
       }
       rbuf = get_memory(rbuf_len);
       mt_com.mt_op = MTFSF;
       mt_com.mt_count = 1;
       while (num-- && !(dev->state & ST_EOT)) {
          Dmsg0(100, "Doing read before fsf\n");
-	 if ((stat = read(dev->fd, (char *)rbuf, rbuf_len)) < 0) {
-	    if (errno == ENOMEM) {     /* tape record exceeds buf len */
-	       stat = rbuf_len;        /* This is OK */
-	    } else {
-	       berrno be;
-	       dev->state |= ST_EOT;
-	       clrerror_dev(dev, -1);
+         if ((stat = read(dev->fd, (char *)rbuf, rbuf_len)) < 0) {
+            if (errno == ENOMEM) {     /* tape record exceeds buf len */
+               stat = rbuf_len;        /* This is OK */
+            } else {
+               berrno be;
+               dev->state |= ST_EOT;
+               clrerror_dev(dev, -1);
                Dmsg2(100, "Set ST_EOT read errno=%d. ERR=%s\n", dev->dev_errno,
-		  be.strerror());
+                  be.strerror());
                Mmsg2(dev->errmsg, _("read error on %s. ERR=%s.\n"),
-		  dev->dev_name, be.strerror());
+                  dev->dev_name, be.strerror());
                Dmsg1(100, "%s", dev->errmsg);
-	       break;
-	    }
-	 }
-	 if (stat == 0) {		 /* EOF */
-	    update_pos_dev(dev);
+               break;
+            }
+         }
+         if (stat == 0) {                /* EOF */
+            update_pos_dev(dev);
             Dmsg1(100, "End of File mark from read. File=%d\n", dev->file+1);
-	    /* Two reads of zero means end of tape */
-	    if (dev->state & ST_EOF) {
-	       dev->state |= ST_EOT;
+            /* Two reads of zero means end of tape */
+            if (dev->state & ST_EOF) {
+               dev->state |= ST_EOT;
                Dmsg0(100, "Set ST_EOT\n");
-	       break;
-	    } else {
-	       dev->state |= ST_EOF;
-	       dev->file++;
-	       dev->file_addr = 0;
-	       dev->file_size = 0;
-	       continue;
-	    }
-	 } else {			 /* Got data */
-	    dev->state &= ~(ST_EOF|ST_EOT);
-	 }
+               break;
+            } else {
+               dev->state |= ST_EOF;
+               dev->file++;
+               dev->file_addr = 0;
+               dev->file_size = 0;
+               continue;
+            }
+         } else {                        /* Got data */
+            dev->state &= ~(ST_EOF|ST_EOT);
+         }
 
          Dmsg0(100, "Doing MTFSF\n");
-	 stat = ioctl(dev->fd, MTIOCTOP, (char *)&mt_com);
-	 if (stat < 0) {		 /* error => EOT */
-	    berrno be;
-	    dev->state |= ST_EOT;
+         stat = ioctl(dev->fd, MTIOCTOP, (char *)&mt_com);
+         if (stat < 0) {                 /* error => EOT */
+            berrno be;
+            dev->state |= ST_EOT;
             Dmsg0(100, "Set ST_EOT\n");
-	    clrerror_dev(dev, MTFSF);
+            clrerror_dev(dev, MTFSF);
             Mmsg2(&dev->errmsg, _("ioctl MTFSF error on %s. ERR=%s.\n"),
-	       dev->dev_name, be.strerror());
+               dev->dev_name, be.strerror());
             Dmsg0(100, "Got < 0 for MTFSF\n");
             Dmsg1(100, "%s", dev->errmsg);
-	 } else {
-	    dev->state |= ST_EOF;     /* just read EOF */
-	    dev->file++;
-	    dev->file_addr = 0;
-	    dev->file_size = 0;
-	 }   
+         } else {
+            dev->state |= ST_EOF;     /* just read EOF */
+            dev->file++;
+            dev->file_addr = 0;
+            dev->file_size = 0;
+         }   
       }
       free_memory(rbuf);
    
@@ -935,14 +935,14 @@ fsf_dev(DEVICE *dev, int num)
    } else {
       Dmsg0(200, "Doing FSR for FSF\n");
       while (num-- && !(dev->state & ST_EOT)) {
-	 fsr_dev(dev, INT32_MAX);    /* returns -1 on EOF or EOT */
+         fsr_dev(dev, INT32_MAX);    /* returns -1 on EOF or EOT */
       }
       if (dev->state & ST_EOT) {
-	 dev->dev_errno = 0;
+         dev->dev_errno = 0;
          Mmsg1(dev->errmsg, _("Device %s at End of Tape.\n"), dev->dev_name);
-	 stat = -1;
+         stat = -1;
       } else {
-	 stat = 0;
+         stat = 0;
       }
    }
    update_pos_dev(dev);
@@ -958,7 +958,7 @@ fsf_dev(DEVICE *dev, int num)
 /* 
  * Backward space a file  
  *  Returns: false on failure
- *	     true  on success
+ *           true  on success
  */
 bool
 bsf_dev(DEVICE *dev, int num)
@@ -975,7 +975,7 @@ bsf_dev(DEVICE *dev, int num)
 
    if (!(dev_state(dev, ST_TAPE))) {
       Mmsg1(dev->errmsg, _("Device %s cannot BSF because it is not a tape.\n"),
-	 dev->dev_name);
+         dev->dev_name);
       return false;
    }
    Dmsg0(29, "bsf_dev\n");
@@ -990,7 +990,7 @@ bsf_dev(DEVICE *dev, int num)
       berrno be;
       clrerror_dev(dev, MTBSF);
       Mmsg2(dev->errmsg, _("ioctl MTBSF error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+         dev->dev_name, be.strerror());
    }
    update_pos_dev(dev);
    return stat == 0;
@@ -1000,7 +1000,7 @@ bsf_dev(DEVICE *dev, int num)
 /* 
  * Foward space a record
  *  Returns: false on failure
- *	     true  on success
+ *           true  on success
  */
 bool
 fsr_dev(DEVICE *dev, int num)
@@ -1038,24 +1038,24 @@ fsr_dev(DEVICE *dev, int num)
 #ifndef HAVE_OPENBSD_OS
       if (ioctl(dev->fd, MTIOCGET, (char *)&mt_stat) == 0 && mt_stat.mt_fileno >= 0) {
          Dmsg4(100, "Adjust from %d:%d to %d:%d\n", dev->file, 
-	    dev->block_num, mt_stat.mt_fileno, mt_stat.mt_blkno);
-	 dev->file = mt_stat.mt_fileno;
-	 dev->block_num = mt_stat.mt_blkno;
+            dev->block_num, mt_stat.mt_fileno, mt_stat.mt_blkno);
+         dev->file = mt_stat.mt_fileno;
+         dev->block_num = mt_stat.mt_blkno;
       } else
 #endif
       {
-	 if (dev->state & ST_EOF) {
-	    dev->state |= ST_EOT;
-	 } else {
-	    dev->state |= ST_EOF;	    /* assume EOF */
-	    dev->file++;
-	    dev->block_num = 0;
-	    dev->file_addr = 0;
-	    dev->file_size = 0;
-	 }
+         if (dev->state & ST_EOF) {
+            dev->state |= ST_EOT;
+         } else {
+            dev->state |= ST_EOF;           /* assume EOF */
+            dev->file++;
+            dev->block_num = 0;
+            dev->file_addr = 0;
+            dev->file_size = 0;
+         }
       }
-      Mmsg2(dev->errmsg, _("ioctl MTFSR error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+      Mmsg3(dev->errmsg, _("ioctl MTFSR %d error on %s. ERR=%s.\n"),
+         num, dev->dev_name, be.strerror());
    }
    update_pos_dev(dev);
    return stat == 0;
@@ -1064,7 +1064,7 @@ fsr_dev(DEVICE *dev, int num)
 /* 
  * Backward space a record
  *   Returns:  false on failure
- *	       true  on success
+ *             true  on success
  */
 bool
 bsr_dev(DEVICE *dev, int num)
@@ -1098,7 +1098,7 @@ bsr_dev(DEVICE *dev, int num)
       berrno be;
       clrerror_dev(dev, MTBSR);
       Mmsg2(dev->errmsg, _("ioctl MTBSR error on %s. ERR=%s.\n"),
-	 dev->dev_name, be.strerror());
+         dev->dev_name, be.strerror());
    }
    update_pos_dev(dev);
    return stat == 0;
@@ -1107,7 +1107,7 @@ bsr_dev(DEVICE *dev, int num)
 /* 
  * Reposition the device to file, block
  * Returns: false on failure
- *	    true  on success
+ *          true  on success
  */
 bool
 reposition_dev(DEVICE *dev, uint32_t file, uint32_t block)
@@ -1123,11 +1123,11 @@ reposition_dev(DEVICE *dev, uint32_t file, uint32_t block)
       off_t pos = (((off_t)file)<<32) + block;
       Dmsg1(100, "===== lseek to %d\n", (int)pos);
       if (lseek(dev->fd, pos, SEEK_SET) == (off_t)-1) {
-	 berrno be;
-	 dev->dev_errno = errno;
+         berrno be;
+         dev->dev_errno = errno;
          Mmsg2(dev->errmsg, _("lseek error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
-	 return false;
+            dev->dev_name, be.strerror());
+         return false;
       }
       dev->file = file;
       dev->block_num = block;
@@ -1139,14 +1139,14 @@ reposition_dev(DEVICE *dev, uint32_t file, uint32_t block)
    if (file < dev->file) {
       Dmsg0(100, "Rewind_dev\n");
       if (!rewind_dev(dev)) {
-	 return false;
+         return false;
       }
    }
    if (file > dev->file) {
       Dmsg1(100, "fsf %d\n", file-dev->file);
       if (!fsf_dev(dev, file-dev->file)) {
          Dmsg1(100, "fsf failed! ERR=%s\n", strerror_dev(dev));
-	 return false;
+         return false;
       }
       Dmsg2(100, "wanted_file=%d at_file=%d\n", file, dev->file);
    }
@@ -1171,7 +1171,7 @@ reposition_dev(DEVICE *dev, uint32_t file, uint32_t block)
 /*
  * Write an end of file on the device
  *   Returns: 0 on success
- *	      non-zero on failure
+ *            non-zero on failure
  */
 int 
 weof_dev(DEVICE *dev, int num)
@@ -1210,7 +1210,7 @@ weof_dev(DEVICE *dev, int num)
       clrerror_dev(dev, MTWEOF);
       if (stat == -1) {
          Mmsg2(dev->errmsg, _("ioctl MTWEOF error on %s. ERR=%s.\n"),
-	    dev->dev_name, be.strerror());
+            dev->dev_name, be.strerror());
        }
    }
    return stat;
@@ -1239,7 +1239,7 @@ clrerror_dev(DEVICE *dev, int func)
    const char *msg = NULL;
    struct mtget mt_stat;
 
-   dev->dev_errno = errno;	   /* save errno */
+   dev->dev_errno = errno;         /* save errno */
    if (errno == EIO) {
       dev->VolCatInfo.VolCatErrors++;
    }
@@ -1251,45 +1251,45 @@ clrerror_dev(DEVICE *dev, int func)
       switch (func) {
       case -1:
          Emsg0(M_ABORT, 0, "Got ENOTTY on read/write!\n");
-	 break;
+         break;
       case MTWEOF:
          msg = "WTWEOF";
-	 dev->capabilities &= ~CAP_EOF; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_EOF; /* turn off feature */
+         break;
 #ifdef MTEOM
       case MTEOM:
          msg = "WTEOM";
-	 dev->capabilities &= ~CAP_EOM; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_EOM; /* turn off feature */
+         break;
 #endif 
       case MTFSF:
          msg = "MTFSF";
-	 dev->capabilities &= ~CAP_FSF; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_FSF; /* turn off feature */
+         break;
       case MTBSF:
          msg = "MTBSF";
-	 dev->capabilities &= ~CAP_BSF; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_BSF; /* turn off feature */
+         break;
       case MTFSR:
          msg = "MTFSR";
-	 dev->capabilities &= ~CAP_FSR; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_FSR; /* turn off feature */
+         break;
       case MTBSR:
          msg = "MTBSR";
-	 dev->capabilities &= ~CAP_BSR; /* turn off feature */
-	 break;
+         dev->capabilities &= ~CAP_BSR; /* turn off feature */
+         break;
       default:
          msg = "Unknown";
-	 break;
+         break;
       }
       if (msg != NULL) {
-	 dev->dev_errno = ENOSYS;
+         dev->dev_errno = ENOSYS;
          Mmsg1(&dev->errmsg, _("This device does not support %s.\n"), msg);
-	 Emsg0(M_ERROR, 0, dev->errmsg);
+         Emsg0(M_ERROR, 0, dev->errmsg);
       }
    }
    /* On some systems such as NetBSD, this clears all errors */
-   ioctl(dev->fd, MTIOCGET, (char *)&mt_stat);	    
+   ioctl(dev->fd, MTIOCGET, (char *)&mt_stat);      
 
 /* Found on Linux */
 #ifdef MTIOCLRERR
@@ -1375,7 +1375,7 @@ close_dev(DEVICE *dev)
    } else if (dev->use_count > 0) {
       dev->use_count--;
    }
-	   
+           
 #ifdef FULL_DEBUG
    ASSERT(dev->use_count >= 0);
 #endif
@@ -1430,7 +1430,7 @@ bool
 dev_can_write(DEVICE *dev)
 {
    if ((dev->state & ST_OPENED) &&  (dev->state & ST_APPEND) &&
-       (dev->state & ST_LABEL)	&& !(dev->state & ST_WEOT)) {
+       (dev->state & ST_LABEL)  && !(dev->state & ST_WEOT)) {
       return true;
    } else {
       return false;
@@ -1505,7 +1505,7 @@ void init_dev_wait_timers(DEVICE *dev)
    /* ******FIXME******* put these on config variables */
    dev->min_wait = 60 * 60;
    dev->max_wait = 24 * 60 * 60;
-   dev->max_num_wait = 9;	       /* 5 waits =~ 1 day, then 1 day at a time */
+   dev->max_num_wait = 9;              /* 5 waits =~ 1 day, then 1 day at a time */
    dev->wait_sec = dev->min_wait;
    dev->rem_wait_sec = dev->wait_sec;
    dev->num_wait = 0;
@@ -1515,11 +1515,11 @@ void init_dev_wait_timers(DEVICE *dev)
 
 /*
  * Returns: true if time doubled
- *	    false if max time expired
+ *          false if max time expired
  */
 bool double_dev_wait_time(DEVICE *dev)
 {
-   dev->wait_sec *= 2;		     /* double wait time */
+   dev->wait_sec *= 2;               /* double wait time */
    if (dev->wait_sec > dev->max_wait) {   /* but not longer than maxtime */
       dev->wait_sec = dev->max_wait;
    }
@@ -1540,18 +1540,18 @@ void set_os_device_parameters(DEVICE *dev)
       mt_com.mt_op = MTSETBLK;
       mt_com.mt_count = 0;
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTSETBLK);
+         clrerror_dev(dev, MTSETBLK);
       }
       mt_com.mt_op = MTSETDRVBUFFER;
       mt_com.mt_count = MT_ST_CLEARBOOLEANS;
       if (!dev_cap(dev, CAP_TWOEOF)) {
-	 mt_com.mt_count |= MT_ST_TWO_FM;
+         mt_com.mt_count |= MT_ST_TWO_FM;
       }
       if (dev_cap(dev, CAP_EOM)) {
-	 mt_com.mt_count |= MT_ST_FAST_MTEOM;
+         mt_com.mt_count |= MT_ST_FAST_MTEOM;
       }
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTSETBLK);
+         clrerror_dev(dev, MTSETBLK);
       }
    }
    return;
@@ -1564,13 +1564,13 @@ void set_os_device_parameters(DEVICE *dev)
       mt_com.mt_op = MTSETBSIZ;
       mt_com.mt_count = 0;
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTSETBSIZ);
+         clrerror_dev(dev, MTSETBSIZ);
       }
       /* Get notified at logical end of tape */
       mt_com.mt_op = MTEWARN;
       mt_com.mt_count = 1;
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTEWARN);
+         clrerror_dev(dev, MTEWARN);
       }
    }
    return;
@@ -1583,7 +1583,7 @@ void set_os_device_parameters(DEVICE *dev)
       mt_com.mt_op = MTSETBSIZ;
       mt_com.mt_count = 0;
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTSETBSIZ);
+         clrerror_dev(dev, MTSETBSIZ);
       }
    }
    return;
@@ -1596,7 +1596,7 @@ void set_os_device_parameters(DEVICE *dev)
       mt_com.mt_op = MTSRSZ;
       mt_com.mt_count = 0;
       if (ioctl(dev->fd, MTIOCTOP, (char *)&mt_com) < 0) {
-	 clrerror_dev(dev, MTSRSZ);
+         clrerror_dev(dev, MTSRSZ);
       }
    }
    return;
