@@ -4,13 +4,13 @@
  * It accepts a number of simple commands from the File daemon
  * and acts on them. When a request to append data is made,
  * it opens a data channel and accepts data from the
- * File daemon. 
+ * File daemon.
+ *
+ *   Version $Id: stored.c,v 1.44.4.2 2005/02/27 21:53:29 kerns Exp $
  *
- *   Version $Id: stored.c,v 1.44 2004/10/18 15:29:00 kerns Exp $
- * 
  */
 /*
-   Copyright (C) 2000-2004 Kern Sibbald and John Walker
+   Copyright (C) 2000-2005 Kern Sibbald
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -65,7 +65,7 @@ static workq_t dird_workq;	      /* queue for processing connections */
 static void usage()
 {
    fprintf(stderr, _(
-"Copyright (C) 2000-2004 Kern Sibbald and John Walker.\n"
+"Copyright (C) 2000-2005 Kern Sibbald.\n"
 "\nVersion: " VERSION " (" BDATE ")\n\n"
 "Usage: stored [options] [-c config_file] [config_file]\n"
 "        -c <file>   use <file> as configuration file\n"
@@ -82,14 +82,14 @@ static void usage()
    exit(1);
 }
 
-/********************************************************************* 
+/*********************************************************************
  *
  *  Main Bacula Unix Storage Daemon
  *
  */
 int main (int argc, char *argv[])
 {
-   int ch;   
+   int ch;
    int no_signals = FALSE;
    int test_config = FALSE;
    pthread_t thid;
@@ -103,9 +103,9 @@ int main (int argc, char *argv[])
    daemon_start_time = time(NULL);
 
    /* Sanity checks */
-   if (TAPE_BSIZE % DEV_BSIZE != 0 || TAPE_BSIZE / DEV_BSIZE == 0) {
+   if (TAPE_BSIZE % B_DEV_BSIZE != 0 || TAPE_BSIZE / B_DEV_BSIZE == 0) {
       Emsg2(M_ABORT, 0, "Tape block size (%d) not multiple of system size (%d)\n",
-	 TAPE_BSIZE, DEV_BSIZE);
+	 TAPE_BSIZE, B_DEV_BSIZE);
    }
    if (TAPE_BSIZE != (1 << (ffs(TAPE_BSIZE)-1))) {
       Emsg1(M_ABORT, 0, "Tape block size (%d) is not a power of 2\n", TAPE_BSIZE);
@@ -123,7 +123,7 @@ int main (int argc, char *argv[])
       case 'd':                    /* debug level */
 	 debug_level = atoi(optarg);
 	 if (debug_level <= 0) {
-	    debug_level = 1; 
+	    debug_level = 1;
 	 }
 	 break;
 
@@ -159,7 +159,7 @@ int main (int argc, char *argv[])
       default:
 	 usage();
 	 break;
-      }  
+      }
    }
    argc -= optind;
    argv += optind;
@@ -169,7 +169,7 @@ int main (int argc, char *argv[])
 	 free(configfile);
       }
       configfile = bstrdup(*argv);
-      argc--; 
+      argc--;
       argv++;
    }
    if (argc)
@@ -179,7 +179,6 @@ int main (int argc, char *argv[])
       init_signals(terminate_stored);
    }
 
-
    if (configfile == NULL) {
       configfile = bstrdup(CONFIG_FILE);
    }
@@ -206,7 +205,7 @@ int main (int argc, char *argv[])
     */
    VolSessionTime = (long)daemon_start_time;
    if (VolSessionTime == 0) { /* paranoid */
-      Emsg0(M_ABORT, 0, _("Volume Session Time is ZERO!\n"));
+      Jmsg0(NULL, M_ABORT, 0, _("Volume Session Time is ZERO!\n"));
    }
 
    /* Make sure on Solaris we can run concurrent, watch dog + servers + misc */
@@ -223,12 +222,12 @@ int main (int argc, char *argv[])
 
    init_jcr_subsystem();	      /* start JCR watchdogs etc. */
 
-   /* 
+   /*
     * Sleep a bit to give device thread a chance to lock the resource
     * chain before we start the server.
     */
    bmicrosleep(1, 0);
-				 
+
    /* Single server used for Director and File daemon */
    bnet_thread_server(me->sdaddrs, me->max_concurrent_jobs * 2 + 1,
 		      &dird_workq, handle_connection_request);
@@ -254,7 +253,7 @@ static void check_config()
    me = (STORES *)GetNextRes(R_STORAGE, NULL);
    if (!me) {
       UnlockRes();
-      Emsg1(M_ERROR_TERM, 0, _("No Storage resource defined in %s. Cannot continue.\n"),
+      Jmsg1(NULL, M_ERROR_TERM, 0, _("No Storage resource defined in %s. Cannot continue.\n"),
 	 configfile);
    }
 
@@ -262,23 +261,23 @@ static void check_config()
 
    if (GetNextRes(R_STORAGE, (RES *)me) != NULL) {
       UnlockRes();
-      Emsg1(M_ERROR_TERM, 0, _("Only one Storage resource permitted in %s\n"), 
+      Jmsg1(NULL, M_ERROR_TERM, 0, _("Only one Storage resource permitted in %s\n"),
 	 configfile);
    }
    if (GetNextRes(R_DIRECTOR, NULL) == NULL) {
       UnlockRes();
-      Emsg1(M_ERROR_TERM, 0, _("No Director resource defined in %s. Cannot continue.\n"),
+      Jmsg1(NULL, M_ERROR_TERM, 0, _("No Director resource defined in %s. Cannot continue.\n"),
 	 configfile);
    }
    if (GetNextRes(R_DEVICE, NULL) == NULL){
       UnlockRes();
-      Emsg1(M_ERROR_TERM, 0, _("No Device resource defined in %s. Cannot continue.\n"),
+      Jmsg1(NULL, M_ERROR_TERM, 0, _("No Device resource defined in %s. Cannot continue.\n"),
 	   configfile);
    }
    if (!me->messages) {
       me->messages = (MSGS *)GetNextRes(R_MSGS, NULL);
       if (!me->messages) {
-         Emsg1(M_ERROR_TERM, 0, _("No Messages resource defined in %s. Cannot continue.\n"),
+         Jmsg1(NULL, M_ERROR_TERM, 0, _("No Messages resource defined in %s. Cannot continue.\n"),
 	    configfile);
       }
    }
@@ -288,16 +287,16 @@ static void check_config()
    UnlockRes();
 
    if (!me->working_directory) {
-      Emsg1(M_ERROR_TERM, 0, _("No Working Directory defined in %s. Cannot continue.\n"),
+      Jmsg1(NULL, M_ERROR_TERM, 0, _("No Working Directory defined in %s. Cannot continue.\n"),
 	 configfile);
    }
-   
+
    set_working_directory(me->working_directory);
 }
 
 /*
- * We are started as a separate thread.  The
- *  resources are alread locked.
+ * Here we attempt to init and open each device. This is done
+ *  once at startup in a separate thread.
  */
 extern "C"
 void *device_allocation(void *arg)
@@ -312,17 +311,17 @@ void *device_allocation(void *arg)
       device->dev = init_dev(NULL, device);
       Dmsg1(10, "SD init done %s\n", device->device_name);
       if (!device->dev) {
-         Emsg1(M_ERROR, 0, _("Could not initialize %s\n"), device->device_name);
+         Jmsg1(NULL, M_ERROR, 0, _("Could not initialize %s\n"), device->device_name);
 	 continue;
       }
 
       if (device->cap_bits & CAP_ALWAYSOPEN) {
          Dmsg1(20, "calling first_open_device %s\n", device->device_name);
 	 if (!first_open_device(device->dev)) {
-            Emsg1(M_ERROR, 0, _("Could not open device %s\n"), device->device_name);
+            Jmsg1(NULL, M_ERROR, 0, _("Could not open device %s\n"), device->device_name);
 	 }
       }
-      if (device->cap_bits & CAP_AUTOMOUNT && device->dev && 
+      if (device->cap_bits & CAP_AUTOMOUNT && device->dev &&
 	  device->dev->state & ST_OPENED) {
 	 JCR *jcr;
 	 DCR *dcr;
@@ -333,19 +332,18 @@ void *device_allocation(void *arg)
 	 if (errstat != 0) {
             Jmsg1(jcr, M_ABORT, 0, _("Unable to init job cond variable: ERR=%s\n"), strerror(errstat));
 	 }
-	 jcr->device = device;
 	 dcr = new_dcr(jcr, device->dev);
 	 switch (read_dev_volume_label(dcr)) {
-	    case VOL_OK:
-	       memcpy(&dcr->dev->VolCatInfo, &dcr->VolCatInfo, sizeof(dcr->dev->VolCatInfo));
-	       break;
-	    default:
-               Emsg1(M_WARNING, 0, _("Could not mount device %s\n"), device->device_name);
-	       break;
+	 case VOL_OK:
+	    memcpy(&dcr->dev->VolCatInfo, &dcr->VolCatInfo, sizeof(dcr->dev->VolCatInfo));
+	    break;
+	 default:
+            Jmsg1(NULL, M_WARNING, 0, _("Could not mount device %s\n"), device->device_name);
+	    break;
 	 }
 	 free_jcr(jcr);
       }
-   } 
+   }
    UnlockRes();
    return NULL;
 }
@@ -378,13 +376,14 @@ void terminate_stored(int sig)
 	    continue;		      /* ignore console */
 	 }
 	 set_jcr_job_status(jcr, JS_Canceled);
-	 fd = jcr->file_bsock;	
+	 fd = jcr->file_bsock;
 	 if (fd) {
 	    fd->timed_out = true;
             Dmsg1(100, "term_stored killing JobId=%d\n", jcr->JobId);
 	    pthread_kill(jcr->my_thread_id, TIMEOUT_SIGNAL);
-	    if (jcr->device && jcr->device->dev && jcr->device->dev->dev_blocked) {
-	       pthread_cond_signal(&jcr->device->dev->wait_next_vol);
+	    /* ***FIXME*** wiffle through all dcrs */
+	    if (jcr->dcr && jcr->dcr->dev && jcr->dcr->dev->dev_blocked) {
+	       pthread_cond_signal(&jcr->dcr->dev->wait_next_vol);
 	    }
 	    bmicrosleep(0, 50000);
 	  }
@@ -403,7 +402,7 @@ void terminate_stored(int sig)
       if (device->dev) {
 	 term_dev(device->dev);
       }
-   } 
+   }
    UnlockRes();
 
    if (configfile)
