@@ -1,8 +1,8 @@
 /* */
 #undef  VERSION
-#define VERSION "1.36.2"
-#define BDATE   "28 February 2005"
-#define LSMDATE "28Feb05"
+#define VERSION "1.36.3"
+#define BDATE   "22 April 2005"
+#define LSMDATE "22Apr05"
 
 /* Debug flags */
 #undef  DEBUG
