@@ -24,7 +24,7 @@
 //
 // Author          : Christopher S. Hull
 // Created On      : Sat Jan 31 15:55:00 2004
-// $Id: compat.cpp,v 1.34.4.2 2005/02/25 09:47:08 kerns Exp $
+// $Id: compat.cpp,v 1.34.4.2.2.1 2005/04/12 21:31:23 kerns Exp $
 
 #include <stdio.h>
 
@@ -120,10 +120,9 @@ int lchown(const char *k, uid_t, gid_t)
 
 bool fstype(const char *fname, char *fs, int fslen)
 {
-   return true;                       /* accept anything */
+   return true;
 }
 
-
 long int
 random(void)
 {
