@@ -4,7 +4,7 @@
  *
  *    Nicolas Boichat, July 2004
  *
- *    Version $Id: wxbmainframe.cpp,v 1.30 2004/11/15 16:49:53 nboichat Exp $
+ *    Version $Id: wxbmainframe.cpp,v 1.30.6.2 2005/03/24 14:52:55 nboichat Exp $
  */
 /*
    Copyright (C) 2004 Kern Sibbald and John Walker
@@ -207,6 +207,8 @@ wxbMainFrame::~wxbMainFrame()
 wxbMainFrame::wxbMainFrame(const wxString& title, const wxPoint& pos, const wxSize& size, long style)
       : wxFrame(NULL, -1, title, pos, size, style)
 {
+   lockedbyconsole = false;
+   
    ct = NULL;
    
    promptparser = NULL;
@@ -313,8 +315,6 @@ wxbMainFrame::wxbMainFrame(const wxString& title, const wxPoint& pos, const wxSi
    this->SetSize(size);
    EnableConsole(false);
    
-   lockedbyconsole = false;
-   
    consoleBuffer = "";
    
    configfile = "";
@@ -647,8 +647,8 @@ void wxbMainFrame::Print(wxString str, int status)
             
             int res = ::wxGetSingleChoiceIndex(message,
                "wx-console: unexpected director's question.", n, choices, this);
-            if (res == -1) {
-               Send("\n");
+            if (res == -1) { //Cancel pressed
+               Send(".\n");
             }
             else {
                if (promptparser->isNumericalChoice()) {
