@@ -4,7 +4,7 @@
  *
  *    Nicolas Boichat, April-May 2004
  *
- *    Version $Id: wxbrestorepanel.h,v 1.19 2004/07/18 09:33:26 kerns Exp $
+ *    Version $Id: wxbrestorepanel.h,v 1.19.10.1 2005/03/24 14:52:56 nboichat Exp $
  */
 /*
    Copyright (C) 2004 Kern Sibbald and John Walker
@@ -151,7 +151,7 @@ class wxbRestorePanel : public wxbPanel
       bool working; // A command is running, discard GUI events
       void SetWorking(bool working);
       bool IsWorking();
-      bool markWhenListingDone;
+      bool markWhenCommandDone; //If an item should be (un)marked after the current listing/marking is done
       wxTreeItemId currentTreeItem; // Currently selected tree item
 
       /* Enable or disable config controls status */
